
# Slot: term

A generic slot for ontology terms

URI: [gocam:EnabledByProteinComplexAssociation_term](https://w3id.org/gocam/EnabledByProteinComplexAssociation_term)


## Domain and Range

[EnabledByProteinComplexAssociation](EnabledByProteinComplexAssociation.md) &#8594;  <sub>0..1</sub> [ProteinComplexTermObject](ProteinComplexTermObject.md)

## Parents

 *  is_a: [➞term](enabledByAssociation__term.md)

## Children


## Used by

 * [EnabledByProteinComplexAssociation](EnabledByProteinComplexAssociation.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | gocam:term |
| **Examples:** | | Example({
  'value': 'GO:0032991',
  'description': ('The generic GO entry for a protein complex. If this is the value of `term`, '
     'then members *must* be specified.')
}) |
|  | | Example({'value': 'ComplexPortal:CPX-969', 'description': 'The human Caspase-2 complex'}) |
